@@ -1,7 +1,7 @@
 #
 # Author: Facundo Batista <facundo@taniquetil.com.ar>
 #
-# Copyright 2010-2011 Chicharreros
+# Copyright 2010-2012 Chicharreros
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -37,7 +37,8 @@ FolderData = collections.namedtuple('FolderData',
                                 'node path suggested_path subscribed volume')
 ShareData = collections.namedtuple('ShareData', 'accepted access_level '
                                    'free_bytes name node_id other_username '
-                                   'other_visible_name path volume_id')
+                                   'other_visible_name path volume_id '
+                                   'subscribed')
 PublicFilesData = collections.namedtuple('PublicFilesData',
                                          'volume node path public_url')
 
@@ -363,22 +364,22 @@ class DBusInterface(object):
     def start(self):
         """Start SDT."""
         logger.info("Calling start")
-        self.sync_daemon_tool.start()
+        return self.sync_daemon_tool.start()
 
     def quit(self):
         """Stop SDT."""
         logger.info("Calling quit")
-        self.sync_daemon_tool.quit()
+        return self.sync_daemon_tool.quit()
 
     def connect(self):
         """Connect SDT."""
         logger.info("Calling connect")
-        self.sync_daemon_tool.connect()
+        return self.sync_daemon_tool.connect()
 
     def disconnect(self):
         """Disconnect SDT."""
         logger.info("Calling disconnect")
-        self.sync_daemon_tool.disconnect()
+        return self.sync_daemon_tool.disconnect()
 
     @defer.inlineCallbacks
     def is_sd_started(self):
@@ -407,6 +408,7 @@ class DBusInterface(object):
                 other_visible_name=d['other_visible_name'],
                 path=d['path'],
                 volume_id=d['volume_id'],
+                subscribed=bool(d['subscribed']),
             )
             all_items.append(s)
         return all_items
