@@ -18,7 +18,9 @@
 
 """Tests for the listings widgets."""
 
-import gtk
+# pylint: disable=E0611
+from gi.repository import Gtk
+# pylint: enable=E0611
 
 from twisted.internet import defer
 
@@ -42,7 +44,6 @@ from magicicada.gui.gtk.listings import (
 )
 from magicicada.gui.gtk.tests import (
     BaseTestCase,
-    FakedSyncdaemon,
     SAMPLE_FOLDERS,
     SAMPLE_SHARES_TO_ME,
     SAMPLE_SHARES_TO_OTHERS,
@@ -106,7 +107,7 @@ class TestDataField(object):
         self._attrs = attrs
         for i in xrange(attrs):
             attr_name = 'attr%i' % i
-            setattr(self, attr_name, '%s-%i' % (prefix, i))
+            setattr(self, attr_name, u'%s-%i' % (prefix, i))
 
     def __len__(self):
         return self._attrs
@@ -115,7 +116,7 @@ class TestDataField(object):
 class FakeDialog(Recorder):
     """A Fake Dialog that knows how to run and hide itself."""
 
-    response = gtk.RESPONSE_NONE
+    response = Gtk.ResponseType.NONE
     no_wrap = ['_called', 'response', 'args', 'kwargs']
 
     def __init__(self, *args, **kwargs):
@@ -137,21 +138,19 @@ class ListingDialogTestCase(BaseTestCase):
 
     @defer.inlineCallbacks
     def setUp(self):
-        self.patch(gtk, 'FileChooserDialog', FakeDialog)
-        self.patch(gtk, 'MessageDialog', FakeDialog)
+        self.patch(Gtk, 'FileChooserDialog', FakeDialog)
+        self.patch(Gtk, 'MessageDialog', FakeDialog)
 
         if self.ui_class.data_fields is None:
-            fakes = (('attr0', lambda s: ''.join(reversed(s))),
-                     ('attr1', lambda s: s.replace('-', ' ❥ ')))
+            fakes = (('attr0', lambda s: u''.join(reversed(s))),
+                     ('attr1', lambda s: s.replace(u'-', u' ❥ ')))
             self.patch(self.ui_class, 'data_fields', fakes)
 
         if self.ui_class.sd_attr is None:
             self.patch(self.ui_class, 'sd_attr', 'fake_sd_attr')
 
-        self.kwargs['syncdaemon_instance'] = FakedSyncdaemon()
-        self.addCleanup(self.kwargs.pop, 'syncdaemon_instance')
         if self.ui_class.filename is None:
-            builder = gtk.Builder()
+            builder = Gtk.Builder()
             builder.add_from_string(TEST_UI)
             self.kwargs['builder'] = builder
             self.addCleanup(self.kwargs.pop, 'builder')
@@ -208,8 +207,9 @@ class ListingDialogTestCase(BaseTestCase):
             self.assertFalse(other_column.get_sort_indicator(),
                              msg % (other_column.get_name(), 'off'))
 
-    def assert_on_toogle_renderer_toggled(self, path, value, column, item_id,
-                                          activate_op, deactivate_op):
+    def assert_on_toggle_renderer_toggled(self, path, value, column, item_id,
+                                          activate_op, deactivate_op,
+                                          toggled_cb):
         """When a toggle renderer is toggled, the backend is called.
 
         - 'path' is the tree path to the row being tested.
@@ -225,7 +225,7 @@ class ListingDialogTestCase(BaseTestCase):
         self.ui.load()
         assert getattr(self.ui.sd, self.ui.sd_attr) == self.items
 
-        self.ui.on_toggle_renderer_toggled(object(), path)
+        toggled_cb(object(), path)
 
         op = deactivate_op if value else activate_op
         self.assert_method_called(self.ui.sd, op, item_id)
@@ -235,7 +235,7 @@ class ListingDialogTestCase(BaseTestCase):
         self.assertEqual(value,
                          self.ui.store.get_value(tree_iter, column))
 
-        self.ui.on_toggle_renderer_toggled(object(), path)
+        toggled_cb(object(), path)
 
         op = deactivate_op if value else activate_op
         self.assert_method_called(self.ui.sd, op, item_id)
@@ -247,7 +247,7 @@ class ListingDialogTestCase(BaseTestCase):
 
     def test_syncdaemon_instance(self):
         """The syncdaemon_instance is correct."""
-        self.assertIs(self.ui.sd, self.kwargs['syncdaemon_instance'])
+        self.assertIs(self.ui.sd, self.sd)
 
     def test_visible(self):
         """The widget is not visible."""
@@ -259,15 +259,15 @@ class ListingDialogTestCase(BaseTestCase):
         buttons = self.ui.get_action_area().get_children()
         self.assertTrue(len(buttons) > 0)
 
-        # with the gtk.STOCK_CLOSE stock
+        # with the Gtk.STOCK_CLOSE stock
         close_button = buttons[-1]
         self.assertIs(self.ui.close_button, close_button)
         self.assertTrue(close_button.get_use_stock())
         stock = close_button.get_image().get_stock()
-        self.assertEqual(stock, (gtk.STOCK_CLOSE, gtk.ICON_SIZE_BUTTON))
+        self.assertEqual(stock, (Gtk.STOCK_CLOSE, Gtk.IconSize.BUTTON))
 
-        # that emits gtk.RESPONSE_CLOSE when clicked
-        widget = self.ui.get_widget_for_response(gtk.RESPONSE_CLOSE)
+        # that emits Gtk.ResponseType.CLOSE when clicked
+        widget = self.ui.get_widget_for_response(Gtk.ResponseType.CLOSE)
         self.assertIs(widget, close_button)
 
     def test_warning_label(self):
@@ -330,19 +330,19 @@ class ListingDialogTestCase(BaseTestCase):
         """The panel can be re-sorted."""
         for idx, col in enumerate(self.ui.view.get_columns()):
             col.clicked()  # click on the column
-            self.assert_sort_order_correct(col, idx, gtk.SORT_ASCENDING)
+            self.assert_sort_order_correct(col, idx, Gtk.SortType.ASCENDING)
             self.assert_sort_indicator_correct(col)
 
             col.clicked()  # click on the column, sort order must change
-            self.assert_sort_order_correct(col, idx, gtk.SORT_DESCENDING)
+            self.assert_sort_order_correct(col, idx, Gtk.SortType.DESCENDING)
 
             col.clicked()  # click again, sort order must be the first one
-            self.assert_sort_order_correct(col, idx, gtk.SORT_ASCENDING)
+            self.assert_sort_order_correct(col, idx, Gtk.SortType.ASCENDING)
 
     def test_view_selection_single(self):
         """The view selection's mode is SINGLE."""
         self.assertEqual(self.ui.view.get_selection().get_mode(),
-                         gtk.SELECTION_SINGLE)
+                         Gtk.SelectionMode.SINGLE)
 
     def test_on_error(self, exc=None):
         """On error 'exc', show a error dialog."""
@@ -358,15 +358,16 @@ class ListingDialogTestCase(BaseTestCase):
 
     def test_confirm_dialog(self):
         """The confirm dialog dialog is properly created."""
-        self.assertIsInstance(self.ui.confirm_dialog, gtk.MessageDialog)
+        self.assertIsInstance(self.ui.confirm_dialog, Gtk.MessageDialog)
 
     def test_confirm_dialog_creation_params(self):
         """The confirm dialog dialog is created with the expected params."""
         self.assertEqual(self.ui.confirm_dialog.args, ())
+        flags = Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT
         kwargs = dict(parent=self.ui,
-                      flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-                      type=gtk.MESSAGE_QUESTION,
-                      buttons=gtk.BUTTONS_YES_NO)
+                      flags=flags,
+                      type=Gtk.MessageType.QUESTION,
+                      buttons=Gtk.ButtonsType.YES_NO)
         self.assertEqual(self.ui.confirm_dialog.kwargs, kwargs)
 
     def test_confirm_dialog_title(self):
@@ -430,28 +431,29 @@ class FoldersDialogTestCase(ListingDialogTestCase):
 
     def test_file_chooser(self):
         """The file chooser dialog is properly created."""
-        self.assertIsInstance(self.ui.file_chooser, gtk.FileChooserDialog)
+        self.assertIsInstance(self.ui.file_chooser, Gtk.FileChooserDialog)
 
         self.assertEqual(self.ui.file_chooser.args, ())
         kwargs = dict(title=ADD_NEW_FOLDER, parent=None,
-                      action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                      buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                               gtk.STOCK_OPEN, gtk.RESPONSE_ACCEPT))
+                      action=Gtk.FileChooserAction.SELECT_FOLDER,
+                      buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                               Gtk.STOCK_OPEN, Gtk.ResponseType.ACCEPT))
         self.assertEqual(self.ui.file_chooser.kwargs, kwargs)
 
-    def test_on_toggle_renderer_toggled(self):
+    def test_on_subscribed_renderer_toggled(self):
         """When subscribed is toggled, the backend is called."""
         path = '1'
         subscribed = self.items[int(path)].subscribed
         item_id = self.items[int(path)].volume
-        self.assert_on_toogle_renderer_toggled(path=path, column=1,
+        self.assert_on_toggle_renderer_toggled(path=path, column=1,
             value=subscribed, item_id=item_id,
-            activate_op='subscribe_folder', deactivate_op='unsubscribe_folder')
+            activate_op='subscribe_folder', deactivate_op='unsubscribe_folder',
+            toggled_cb=self.ui.on_subscribed_renderer_toggled)
 
     @defer.inlineCallbacks
     def test_on_add_folder_button_clicked_file_chooser_cancel(self):
         """When the file choosing is canceled, the backend is not called."""
-        self.patch(self.ui.file_chooser, 'response', gtk.RESPONSE_CANCEL)
+        self.patch(self.ui.file_chooser, 'response', Gtk.ResponseType.CANCEL)
         yield self.ui.add_folder_button.clicked()
 
         self.assert_methods_called(self.ui.file_chooser, ['run', 'hide'])
@@ -461,7 +463,7 @@ class FoldersDialogTestCase(ListingDialogTestCase):
     @defer.inlineCallbacks
     def test_on_add_folder_button_clicked_file_chooser_close(self):
         """When the file choosing is closed, the backend is not called."""
-        self.patch(self.ui.file_chooser, 'response', gtk.RESPONSE_CLOSE)
+        self.patch(self.ui.file_chooser, 'response', Gtk.ResponseType.CLOSE)
         yield self.ui.add_folder_button.clicked()
 
         self.assert_methods_called(self.ui.file_chooser, ['run', 'hide'])
@@ -472,7 +474,7 @@ class FoldersDialogTestCase(ListingDialogTestCase):
     def test_on_add_folder_button_clicked_file_chooser_accept(self):
         """When the add_folder_button is clicked, the backend is called."""
         self.patch(self.ui, 'load', self._set_called)
-        self.patch(self.ui.file_chooser, 'response', gtk.RESPONSE_ACCEPT)
+        self.patch(self.ui.file_chooser, 'response', Gtk.ResponseType.ACCEPT)
 
         def check():
             """Perform a middle check."""
@@ -515,7 +517,7 @@ class FoldersDialogRemoveFolderTestCase(FoldersDialogTestCase):
 
     def test_remove_folder_button_disabled(self):
         """When there is no folder selected, the remove button is disabled."""
-        self.ui.view.get_selection().unselect_path('0')
+        self.ui.view.get_selection().unselect_all()
         self.ui.on_view_cursor_changed()
         self.assertFalse(self.ui.remove_folder_button.get_sensitive())
 
@@ -540,7 +542,7 @@ class FoldersDialogRemoveFolderTestCase(FoldersDialogTestCase):
     def test_on_remove_folder_button_clicked_closes_dialog(self):
         """If the user closes the dialog, nothing is done."""
         self.patch(self.ui.confirm_dialog, 'response',
-                   gtk.RESPONSE_DELETE_EVENT)
+                   Gtk.ResponseType.DELETE_EVENT)
         yield self.ui.remove_folder_button.clicked()
 
         self.assert_no_method_called(self.ui.sd)
@@ -549,7 +551,7 @@ class FoldersDialogRemoveFolderTestCase(FoldersDialogTestCase):
     @defer.inlineCallbacks
     def test_on_remove_folder_button_clicked_answers_no(self):
         """If the user answers no, nothing is done."""
-        self.patch(self.ui.confirm_dialog, 'response', gtk.RESPONSE_NO)
+        self.patch(self.ui.confirm_dialog, 'response', Gtk.ResponseType.NO)
         yield self.ui.remove_folder_button.clicked()
 
         self.assert_no_method_called(self.ui.sd)
@@ -558,7 +560,7 @@ class FoldersDialogRemoveFolderTestCase(FoldersDialogTestCase):
     @defer.inlineCallbacks
     def test_on_remove_folder_button_clicked_answers_yes(self):
         """If the user answers yes, sd.delete_folder is called."""
-        self.patch(self.ui.confirm_dialog, 'response', gtk.RESPONSE_YES)
+        self.patch(self.ui.confirm_dialog, 'response', Gtk.ResponseType.YES)
 
         def check():
             """Perform a middle check."""
@@ -578,14 +580,26 @@ class SharesToMeDialogTestCase(ListingDialogTestCase):
     items = SAMPLE_SHARES_TO_ME
     ui_class = SharesToMeDialog
 
-    def test_on_toggle_renderer_toggled(self):
+    def test_on_accepted_renderer_toggled(self):
         """When accepted is toggled, the backend is called."""
         path = '0'
         accepted = self.items[int(path)].accepted
         item_id = self.items[int(path)].volume_id
-        self.assert_on_toogle_renderer_toggled(path=path, column=2,
+        self.assert_on_toggle_renderer_toggled(path=path, column=2,
             value=accepted, item_id=item_id,
-            activate_op='accept_share', deactivate_op='reject_share')
+            activate_op='accept_share', deactivate_op='reject_share',
+            toggled_cb=self.ui.on_accepted_renderer_toggled)
+
+    def test_on_subscribed_renderer_toggled(self):
+        """When subscribed is toggled, the backend is called."""
+        path = '0'
+        subscribed = self.items[int(path)].subscribed
+        item_id = self.items[int(path)].volume_id
+        self.assert_on_toggle_renderer_toggled(path=path, column=3,
+            value=subscribed, item_id=item_id,
+            activate_op='subscribe_share',
+            deactivate_op='unsubscribe_share',
+            toggled_cb=self.ui.on_subscribed_renderer_toggled)
 
 
 class SharesToOthersDialogTestCase(ListingDialogTestCase):
@@ -605,7 +619,6 @@ class PublicFilesDialogTestCase(ListingDialogTestCase):
 class ListingButtonTestCase(BaseTestCase):
     """Test case for the ListingButton widget."""
 
-    kwargs = {'syncdaemon_instance': FakedSyncdaemon()}
     label = None
     stock_id = None
     ui_class = ListingButton
@@ -626,8 +639,7 @@ class ListingButtonTestCase(BaseTestCase):
     def test_dialog(self):
         """The dialog is correct."""
         self.assertIsInstance(self.ui.dialog, FakeDialog)
-        self.assertEqual(self.ui.dialog.args,
-                         (self.kwargs['syncdaemon_instance'],))
+        self.assertEqual(self.ui.dialog.args, (self.sd,))
         self.assertEqual(self.ui.dialog.kwargs, {})
 
     def test_visible(self):
