@@ -1,8 +1,4 @@
-# syncdaemon.py
-#
-# Author: Facundo Batista <facundo@taniquetil.com.ar>
-#
-# Copyright 2010-2011 Chicharreros
+# Copyright 2010-2012 Chicharreros
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -45,11 +41,12 @@ TRANSFER_POLL_INTERVAL = 5
 
 # status of the node
 CHANGED_NONE, CHANGED_SERVER, CHANGED_LOCAL = \
-                                "synchronized downloading uploading".split()
+    "synchronized downloading uploading".split()
 
 # state of SD
-STATE_IDLE, STATE_WORKING, STATE_ALERT, STATE_STOPPED, STATE_STARTED = \
-                                "idle working alert stopped started".split()
+STATE_STOPPED, STATE_IDLE, STATE_WORKING, STATE_CONNECTING, STATE_STARTING, \
+STATE_DISCONNECTED = \
+    "stopped idle working connecting starting disconnected".split()
 
 
 def mandatory_callback(function_name):
@@ -67,9 +64,6 @@ class State(object):
     _attrs = ['name', 'description', 'is_error', 'is_connected',
               'is_online', 'queues', 'connection', 'is_started', 'state']
 
-    _meta = ('WORKING_ON_METADATA', 'WORKING_ON_BOTH')
-    _content = ('WORKING_ON_CONTENT', 'WORKING_ON_BOTH')
-
     def __init__(self):
         # starting defaults
         self.name = ''
@@ -80,16 +74,12 @@ class State(object):
         self.queues = ''
         self.connection = ''
         self.is_started = False
-        self.state = STATE_IDLE
+        self.state = STATE_STOPPED
 
     def __getattribute__(self, name):
         """Return the value if there."""
         if name[0] == "_" or name == 'set':
             return object.__getattribute__(self, name)
-        elif name == 'processing_meta':
-            return self.__dict__['queues'] in self._meta
-        elif name == 'processing_content':
-            return self.__dict__['queues'] in self._content
         else:
             return self.__dict__[name]
 
@@ -293,8 +283,6 @@ class SyncDaemon(object):
                       is_error=is_error, is_connected=is_connected,
                       is_online=is_online, queues=queues,
                       connection=connection)
-        xs = sorted(kwargs.iteritems())
-        logger.debug("    new status: %s", ', '.join('%s=%r' % i for i in xs))
 
         # check status changes to call other callbacks
         if is_connected and not self.current_state.is_connected:
@@ -307,23 +295,36 @@ class SyncDaemon(object):
             self.on_offline_callback()
 
         # state of SD
-        if name == "QUEUE_MANAGER" and queues == "IDLE":
-            state = STATE_IDLE
-        elif name == "QUEUE_MANAGER" and queues == "WORKING":
-            state = STATE_WORKING
-        elif name == "LOCAL_RESCAN":
-            state = STATE_STARTED
-            if self.current_state.state != STATE_STARTED:
-                self.current_state.set(is_started=True)
-                self.on_started_callback()
-                self._get_initial_data()
-        elif name == "SHUTDOWN":
+        if name == "SHUTDOWN":
+            state = STATE_STOPPED
             self.current_state.set(is_started=False)
             self.on_stopped_callback()
-            state = STATE_STOPPED
+        elif name in ('READY', 'WAITING'):
+            if connection == 'With User With Network':
+                state = STATE_CONNECTING
+            else:
+                state = STATE_DISCONNECTED
+        elif name == 'STANDOFF':
+            state = STATE_DISCONNECTED
         else:
-            state = STATE_ALERT
+            if is_connected:
+                if name == "QUEUE_MANAGER":
+                    if queues == "IDLE":
+                        state = STATE_IDLE
+                    else:
+                        state = STATE_WORKING
+                else:
+                    state = STATE_CONNECTING
+            else:
+                state = STATE_STARTING
+                # check if it's the first time we flag starting
+                if self.current_state.state != STATE_STARTING:
+                    self.current_state.set(is_started=True)
+                    self.on_started_callback()
+                    self._get_initial_data()
         kwargs['state'] = state
+        xs = sorted(kwargs.iteritems())
+        logger.debug("    new status: %s", ', '.join('%s=%r' % i for i in xs))
 
         # set current state to new values and call status changed cb
         self.current_state.set(**kwargs)
@@ -355,23 +356,24 @@ class SyncDaemon(object):
     def start(self):
         """Start the SyncDaemon."""
         logger.info("Starting u1.SD")
-        self.dbus.start()
+        d = self.dbus.start()
         self._get_initial_data()
+        return d
 
     def quit(self):
         """Stop the SyncDaemon and makes it quit."""
         logger.info("Stopping u1.SD")
-        self.dbus.quit()
+        return self.dbus.quit()
 
     def connect(self):
         """Tell the SyncDaemon that the user wants it to connect."""
         logger.info("Telling u1.SD to connect")
-        self.dbus.connect()
+        return self.dbus.connect()
 
     def disconnect(self):
         """Tell the SyncDaemon that the user wants it to disconnect."""
         logger.info("Telling u1.SD to disconnect")
-        self.dbus.disconnect()
+        return self.dbus.disconnect()
 
     @defer.inlineCallbacks
     def get_metadata(self, path):
