@@ -1,7 +1,7 @@
 #
 # Author: Facundo Batista <facundo@taniquetil.com.ar>
 #
-# Copyright 2010-2011 Chicharreros
+# Copyright 2010-2012 Chicharreros
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -117,7 +117,7 @@ class SafeTestCase(TwistedTestCase):
         logger = logging.getLogger('magicicada.dbusiface')
         logger.addHandler(self.handler)
         logger.setLevel(logging.DEBUG)
-        self.addCleanup(lambda: logger.removeHandler(self.handler))
+        self.addCleanup(logger.removeHandler, self.handler)
 
         self.patch(dbusiface, 'SessionBus', FakeSessionBus)
         self.patch(dbusiface, 'SyncDaemonTool', FakeSDTool)
@@ -481,7 +481,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         d = dict(accepted=u'True', access_level=u'View', free_bytes=u'123456',
                  name=u'foobar', node_id=u'node', other_username=u'johndoe',
                  other_visible_name=u'John Doe', path=u'path',
-                 volume_id=u'vol', type=u'Share')
+                 volume_id=u'vol', type=u'Share', subscribed='')
         self.fake_sdt_response('get_shares', [d])
         rcv = yield self.dbus.get_shares_to_me()
         self.assertEqual(len(rcv), 1)
@@ -494,7 +494,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         self.assertEqual(share.other_username, 'johndoe')
         self.assertEqual(share.other_visible_name, 'John Doe')
         self.assertEqual(share.path, 'path')
-        self.assertEqual(share.volume_id, 'vol')
+        self.assertEqual(share.subscribed, False)
 
     @defer.inlineCallbacks
     def test_sharestoother_one(self):
@@ -502,7 +502,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         d = dict(accepted=u'True', access_level=u'View', free_bytes=u'123456',
                  name=u'foobar', node_id=u'node', other_username=u'johndoe',
                  other_visible_name=u'John Doe', path=u'path',
-                 volume_id=u'vol', type=u'Shared')
+                 volume_id=u'vol', type=u'Shared', subscribed='True')
         self.fake_sdt_response('list_shared', [d])
         rcv = yield self.dbus.get_shares_to_others()
         self.assertEqual(len(rcv), 1)
@@ -516,6 +516,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         self.assertEqual(share.other_visible_name, 'John Doe')
         self.assertEqual(share.path, 'path')
         self.assertEqual(share.volume_id, 'vol')
+        self.assertEqual(share.subscribed, True)
 
     @defer.inlineCallbacks
     def test_sharestoother_two(self):
@@ -523,11 +524,11 @@ class DataProcessingSharesTestCase(SafeTestCase):
         d1 = dict(accepted=u'True', access_level=u'View', free_bytes=u'123456',
                   name=u'foobar', node_id=u'node', other_username=u'johndoe',
                   other_visible_name=u'John Doe', path=u'path',
-                  volume_id=u'vol', type=u'Shared')
+                  volume_id=u'vol', type=u'Shared', subscribed='')
         d2 = dict(accepted=u'', access_level=u'Modify', free_bytes=u'789',
                   name=u'rulo', node_id=u'node', other_username=u'nn',
                   other_visible_name=u'Ene Ene', path=u'path',
-                  volume_id=u'vol', type=u'Shared')
+                  volume_id=u'vol', type=u'Shared', subscribed='True')
         self.fake_sdt_response('list_shared', [d1, d2])
         rcv = yield self.dbus.get_shares_to_others()
         self.assertEqual(len(rcv), 2)
@@ -541,6 +542,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         self.assertEqual(share.other_visible_name, 'John Doe')
         self.assertEqual(share.path, 'path')
         self.assertEqual(share.volume_id, 'vol')
+        self.assertEqual(share.subscribed, False)
         share = rcv[1]
         self.assertEqual(share.accepted, False)
         self.assertEqual(share.access_level, 'Modify')
@@ -551,6 +553,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         self.assertEqual(share.other_visible_name, 'Ene Ene')
         self.assertEqual(share.path, 'path')
         self.assertEqual(share.volume_id, 'vol')
+        self.assertEqual(share.subscribed, True)
 
     def test_shares_changed_from_created(self):
         """Test shares changed callback from created."""
@@ -573,7 +576,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         d = dict(accepted=u'True', access_level=u'View', free_bytes=u'',
                  name=u'foobar', node_id=u'node', other_username=u'johndoe',
                  other_visible_name=u'John Doe', path=u'path',
-                 volume_id=u'vol', type=u'Share')
+                 volume_id=u'vol', type=u'Share', subscribed='True')
         self.fake_sdt_response('get_shares', [d])
         rcv = yield self.dbus.get_shares_to_me()
         self.assertEqual(len(rcv), 1)
@@ -587,6 +590,7 @@ class DataProcessingSharesTestCase(SafeTestCase):
         self.assertEqual(share.other_visible_name, 'John Doe')
         self.assertEqual(share.path, 'path')
         self.assertEqual(share.volume_id, 'vol')
+        self.assertEqual(share.subscribed, True)
 
 
 class PublicFilesTestCase(SafeTestCase):
@@ -741,23 +745,27 @@ class ToolActionsTestCase(SafeTestCase):
 
     def test_start(self):
         """Test call to start."""
-        self.dbus.start()
+        res = self.dbus.start()
         self.check_sdt_called("start")
+        self.assertIsInstance(res, defer.Deferred)
 
     def test_quit(self):
         """Test call to quit."""
-        self.dbus.quit()
+        res = self.dbus.quit()
         self.check_sdt_called("quit")
+        self.assertIsInstance(res, defer.Deferred)
 
     def test_connect(self):
         """Test call to connect."""
-        self.dbus.connect()
+        res = self.dbus.connect()
         self.check_sdt_called("connect")
+        self.assertIsInstance(res, defer.Deferred)
 
     def test_disconnect(self):
         """Test call to disconnect."""
-        self.dbus.disconnect()
+        res = self.dbus.disconnect()
         self.check_sdt_called("disconnect")
+        self.assertIsInstance(res, defer.Deferred)
 
 
 class LogsTestCase(SafeTestCase):
@@ -936,7 +944,7 @@ class LogsTestCase(SafeTestCase):
         d = dict(accepted=u'True', access_level=u'View', free_bytes=u'123456',
                  name=u'foobar', node_id=u'node', other_username=u'johndoe',
                  other_visible_name=u'John Doe', path=u'path',
-                 volume_id=u'vol', type=u'Share')
+                 volume_id=u'vol', type=u'Share', subscribed='')
         self.fake_sdt_response('get_shares', [d])
         yield self.dbus.get_shares_to_me()
         self.assertTrue(self.handler.check_info(
@@ -949,7 +957,7 @@ class LogsTestCase(SafeTestCase):
         d = dict(accepted=u'True', access_level=u'View', free_bytes=u'123456',
                  name=u'foobar', node_id=u'node', other_username=u'johndoe',
                  other_visible_name=u'John Doe', path=u'path',
-                 volume_id=u'vol', type=u'Shared')
+                 volume_id=u'vol', type=u'Shared', subscribed='True')
         self.fake_sdt_response('list_shared', [d])
         yield self.dbus.get_shares_to_others()
         self.assertTrue(self.handler.check_info(
