@@ -152,7 +152,7 @@ class NodeStructureTestCase(unittest.TestCase):
         logger = logging.getLogger('magicicada.queue_content')
         logger.addHandler(self.handler)
         logger.setLevel(logging.DEBUG)
-        self.addCleanup(lambda: logger.removeHandler(self.handler))
+        self.addCleanup(logger.removeHandler, self.handler)
 
     def test_one_node_file(self):
         """Add one node with a file op."""
