@@ -1,8 +1,4 @@
-# Tests for the SyncDaemon interface
-#
-# Author: Facundo Batista <facundo@taniquetil.com.ar>
-#
-# Copyright 2010-2011 Chicharreros
+# Copyright 2010-2012 Chicharreros
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -41,15 +37,16 @@ from magicicada.syncdaemon import (
     INTERNAL_OP,
     NODE_OP,
     Poller,
+    STATE_CONNECTING,
+    STATE_DISCONNECTED,
+    STATE_IDLE,
+    STATE_STARTING,
+    STATE_STOPPED,
+    STATE_WORKING,
     State,
     SyncDaemon,
     TRANSFER_POLL_INTERVAL,
     mandatory_callback,
-    STATE_ALERT,
-    STATE_IDLE,
-    STATE_STARTED,
-    STATE_STOPPED,
-    STATE_WORKING,
 )
 
 
@@ -142,7 +139,7 @@ class BaseTestCase(TwistedTestCase):
         logger = logging.getLogger('magicicada.syncdaemon')
         logger.addHandler(self.hdlr)
         logger.setLevel(logging.DEBUG)
-        self.addCleanup(lambda: logger.removeHandler(self.hdlr))
+        self.addCleanup(logger.removeHandler, self.hdlr)
 
         self.sd = SyncDaemon(FakeDBusInterface)
         self.addCleanup(self.sd.shutdown)
@@ -316,6 +313,28 @@ class StatusChangedTestCase(BaseTestCase):
         yield self.sd._get_initial_data()
         self.assertTrue(called)
 
+    def test_statuschanged_stopped(self):
+        """Test StatusChanged signal with status STOPPED."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'SHUTDOWN')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, True)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'connection')
+            self.assertEqual(state, STATE_STOPPED)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.on_sd_status_changed('SHUTDOWN', 'description', False,
+                                     True, False, 'IDLE', 'connection')
+        return deferred
+
     def test_statuschanged_idle(self):
         """Test StatusChanged signal with status IDLE."""
         deferred = defer.Deferred()
@@ -360,28 +379,166 @@ class StatusChangedTestCase(BaseTestCase):
                                      True, False, 'WORKING', 'connection')
         return deferred
 
-    def test_statuschanged_alert(self):
-        """Test StatusChanged signal with status ALERT."""
+    def test_statuschanged_connecting_after_ready(self):
+        """Test StatusChanged signal with status CONNECTION."""
         deferred = defer.Deferred()
 
         def callback(name, description, is_error, is_connected, is_online,
                      queues, connection, state):
             """Check received data."""
-            self.assertEqual(name, 'not queuemanager')
+            self.assertEqual(name, 'SERVER_RESCAN')
             self.assertEqual(description, 'description')
             self.assertEqual(is_error, False)
             self.assertEqual(is_connected, True)
             self.assertEqual(is_online, False)
             self.assertEqual(queues, 'IDLE')
             self.assertEqual(connection, 'connection')
-            self.assertEqual(state, STATE_ALERT)
+            self.assertEqual(state, STATE_CONNECTING)
             deferred.callback(True)
 
         self.sd.status_changed_callback = callback
-        self.sd.on_sd_status_changed('not queuemanager', 'description', False,
+        self.sd.on_sd_status_changed('SERVER_RESCAN', 'description', False,
                                      True, False, 'IDLE', 'connection')
         return deferred
 
+    def test_statuschanged_starting(self):
+        """Test StatusChanged signal with status STARTING."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'LOCAL_RESCAN')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, False)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'connectn')
+            self.assertEqual(state, STATE_STARTING)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.dbus.get_status = lambda: defer.Deferred()
+        self.sd.on_sd_status_changed('LOCAL_RESCAN', 'description', False,
+                                     False, False, 'IDLE', 'connectn')
+        return deferred
+
+    def test_statuschanged_connecting_ready(self):
+        """Test StatusChanged signal when READY to connect."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'READY')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, False)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'With User With Network')
+            self.assertEqual(state, STATE_CONNECTING)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.dbus.get_status = lambda: defer.Deferred()
+        self.sd.on_sd_status_changed('READY', 'description', False, False,
+                                     False, 'IDLE', 'With User With Network')
+        return deferred
+
+    def test_statuschanged_disconnected_ready(self):
+        """Test StatusChanged signal when READY but not to connect."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'READY')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, False)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'not with both in with')
+            self.assertEqual(state, STATE_DISCONNECTED)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.dbus.get_status = lambda: defer.Deferred()
+        self.sd.on_sd_status_changed('READY', 'description', False, False,
+                                     False, 'IDLE', 'not with both in with')
+        return deferred
+
+    def test_statuschanged_connecting_waiting(self):
+        """Test StatusChanged signal when WAITING to connect."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'WAITING')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, False)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'With User With Network')
+            self.assertEqual(state, STATE_CONNECTING)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.dbus.get_status = lambda: defer.Deferred()
+        self.sd.on_sd_status_changed('WAITING', 'description', False, False,
+                                     False, 'IDLE', 'With User With Network')
+        return deferred
+
+    def test_statuschanged_disconnected_waiting(self):
+        """Test StatusChanged signal when WAITING but not to connect."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'WAITING')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, False)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'not with both in with')
+            self.assertEqual(state, STATE_DISCONNECTED)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.dbus.get_status = lambda: defer.Deferred()
+        self.sd.on_sd_status_changed('WAITING', 'description', False, False,
+                                     False, 'IDLE', 'not with both in with')
+        return deferred
+
+    def test_statuschanged_standoff(self):
+        """Test StatusChanged signal when STANDOFF."""
+        deferred = defer.Deferred()
+
+        def callback(name, description, is_error, is_connected, is_online,
+                     queues, connection, state):
+            """Check received data."""
+            self.assertEqual(name, 'STANDOFF')
+            self.assertEqual(description, 'description')
+            self.assertEqual(is_error, False)
+            self.assertEqual(is_connected, False)
+            self.assertEqual(is_online, False)
+            self.assertEqual(queues, 'IDLE')
+            self.assertEqual(connection, 'With User With Network')
+            self.assertEqual(state, STATE_DISCONNECTED)
+            deferred.callback(True)
+
+        self.sd.status_changed_callback = callback
+        self.sd.dbus.get_status = lambda: defer.Deferred()
+        self.sd.on_sd_status_changed('STANDOFF', 'description', False, False,
+                                     False, 'IDLE', 'With User With Network')
+        return deferred
+
     def test_status_changed_affects_current_status(self):
         """Make changes to see how status are reflected."""
         # one set of values
@@ -435,46 +592,22 @@ class StatusChangedTestCase(BaseTestCase):
         self.assertEqual(self.sd.current_state.is_started, False)
         self.assertTrue(called)
 
-    def test_on_localrescan_firsttime(self):
-        """Got local rescan the first time, goes to started."""
-        called = []
-        self.sd._get_initial_data = lambda: called.append('initial')
-        self.sd.on_started_callback = lambda: called.append('started-cb')
-        assert self.sd.current_state.state != STATE_STARTED
-
-        self.sd.on_sd_status_changed('LOCAL_RESCAN', 'description', False,
-                                     False, False, '', '')
-        self.assertEqual(self.sd.current_state.name, 'LOCAL_RESCAN')
-        self.assertEqual(self.sd.current_state.description, 'description')
-        self.assertEqual(self.sd.current_state.is_error, False)
-        self.assertEqual(self.sd.current_state.is_connected, False)
-        self.assertEqual(self.sd.current_state.is_online, False)
-        self.assertEqual(self.sd.current_state.queues, '')
-        self.assertEqual(self.sd.current_state.connection, '')
-        self.assertEqual(self.sd.current_state.state, STATE_STARTED)
-        self.assertEqual(self.sd.current_state.is_started, True)
-        self.assertIn('initial', called)
-        self.assertIn('started-cb', called)
-
-    def test_on_localrescan_secondtime(self):
-        """Got local rescan the second time."""
-        called = []
-        self.sd._get_initial_data = lambda: called.append('initial')
-        self.sd.on_started_callback = lambda: called.append('started-cb')
-        self.sd.current_state.state = STATE_STARTED
-
-        self.sd.on_sd_status_changed('LOCAL_RESCAN', 'description', False,
-                                     False, False, '', '')
-        self.assertEqual(self.sd.current_state.name, 'LOCAL_RESCAN')
-        self.assertEqual(self.sd.current_state.description, 'description')
-        self.assertEqual(self.sd.current_state.is_error, False)
-        self.assertEqual(self.sd.current_state.is_connected, False)
-        self.assertEqual(self.sd.current_state.is_online, False)
-        self.assertEqual(self.sd.current_state.queues, '')
-        self.assertEqual(self.sd.current_state.connection, '')
-        self.assertEqual(self.sd.current_state.state, STATE_STARTED)
-        self.assertEqual(self.sd.current_state.is_started, True)
-        self.assertFalse(called)
+    def test_logging(self):
+        """Test how the info is logged."""
+        self.sd.on_sd_status_changed('QUEUE_MANAGER', 'description', False,
+                                     True, False, 'IDLE', 'connection')
+        should = (
+            "new status:",
+            "name='QUEUE_MANAGER'",
+            "description='description'",
+            "is_error=False",
+            "is_connected=True",
+            "is_online=False",
+            "queues='IDLE'",
+            "connection='connection'",
+            "state='idle'",
+        )
+        self.assertTrue(self.hdlr.check_debug(*should))
 
 
 class QueueChangedTestCase(BaseTestCase):
@@ -608,7 +741,7 @@ class StateTestCase(unittest.TestCase):
         self.assertRaises(AttributeError, st.set, not_really_allowed=44)
 
 
-class APITestCase(unittest.TestCase):
+class APITestCase(TwistedTestCase):
     """Check exposed methods and attributes."""
 
     def setUp(self):
@@ -624,12 +757,6 @@ class APITestCase(unittest.TestCase):
             setattr(*self._replaced)
         self.sd.shutdown()
 
-    def mpatch_called(self, obj, method_name):
-        """Monkeypatch to flag called."""
-        self._replaced = (obj, method_name, getattr(obj, method_name))
-        f = lambda *a, **k: setattr(self, 'called', True)
-        setattr(obj, method_name, f)
-
     def flag_called(self, obj, method_name):
         """Replace callback to flag called."""
         f = lambda *a, **k: setattr(self, 'called', True)
@@ -637,27 +764,31 @@ class APITestCase(unittest.TestCase):
 
     def test_start(self):
         """Test start calls SD."""
-        self.mpatch_called(self.sd.dbus, 'start')
-        self.sd.start()
-        self.assertTrue(self.called)
+        deferred = object()
+        self.patch(self.sd.dbus, 'start', lambda: deferred)
+        res = self.sd.start()
+        self.assertIdentical(res, deferred)
 
     def test_quit(self):
         """Test quit calls SD."""
-        self.mpatch_called(self.sd.dbus, 'quit')
-        self.sd.quit()
-        self.assertTrue(self.called)
+        deferred = object()
+        self.patch(self.sd.dbus, 'quit', lambda: deferred)
+        res = self.sd.quit()
+        self.assertIdentical(res, deferred)
 
     def test_connect(self):
         """Test connect calls SD."""
-        self.mpatch_called(self.sd.dbus, 'connect')
-        self.sd.connect()
-        self.assertTrue(self.called)
+        deferred = object()
+        self.patch(self.sd.dbus, 'connect', lambda: deferred)
+        res = self.sd.connect()
+        self.assertIdentical(res, deferred)
 
     def test_disconnect(self):
         """Test disconnect calls SD."""
-        self.mpatch_called(self.sd.dbus, 'disconnect')
-        self.sd.disconnect()
-        self.assertTrue(self.called)
+        deferred = object()
+        self.patch(self.sd.dbus, 'disconnect', lambda: deferred)
+        res = self.sd.disconnect()
+        self.assertIdentical(res, deferred)
 
     def test_on_connected(self):
         """Called when SD connected."""
@@ -710,7 +841,7 @@ class LogsTestCase(unittest.TestCase):
         logger = logging.getLogger('magicicada.syncdaemon')
         logger.addHandler(self.hdlr)
         logger.setLevel(logging.DEBUG)
-        self.addCleanup(lambda: logger.removeHandler(self.hdlr))
+        self.addCleanup(logger.removeHandler, self.hdlr)
         self.sd = SyncDaemon(FakeDBusInterface)
 
     def tearDown(self):
